#
# spec file for package sapstartsrv-resource-agents
#
# Copyright (c) 2020-2025 SUSE LLC.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.
#
# Please submit bugfixes or comments via http://bugs.opensuse.org/

%if 0%{?suse_version} < 1600
%bcond_with test
%else
%bcond_without test
%endif

Name:           sapstartsrv-resource-agents
VCS: https://src.suse.de/SLFO-pool/sapstartsrv-resource-agents#38631861d08dc5c8f3b26a820da9b74c3a81569b1df6a3c9572838807583d25e
License:        GPL-2.0
Group:          Productivity/Clustering/HA
Summary:        Resource agent for SAP instance specific sapstartsrv service
Version:        0.9.4+git.1739992536.298b1ce
Release:        160000.1.3
URL:            https://github.com/SUSE/SAPStartSrv-resourceAgent
Source0:        %{name}-%{version}.tar.gz
BuildArch:      noarch
BuildRequires:  resource-agents
Requires:       resource-agents
Requires:       pacemaker > 1.1.1
Requires:       python3
Requires:       python3-psutil
Recommends:     supportutils-plugin-ha-sap
%if %{with test}
BuildRequires:  python3-pytest
BuildRequires:  python3-psutil
%endif

%define raname SAPStartSrv
%define srvname sapservices-move
%define ocf_dir %{_prefix}/lib/ocf

%description
This is a resource agent for the instance specific SAP start framework.
It controls the instance specific sapstartsrv process which provides the
API to start, stop and check an SAP instance.

Authors:
--------
    Fabian Herschel
    Lars Pinne
    Xabier Arbulu

%prep
%setup -q

%build
gzip man/*

%install
install -D -m 0755 ra/%{raname}.in %{buildroot}%{ocf_dir}/resource.d/suse/%{raname}
install -d %{buildroot}%{_mandir}/man7
install -d %{buildroot}%{_mandir}/man8
install -m 0444 man/*.7.gz %{buildroot}%{_mandir}/man7
install -m 0444 man/*.8.gz %{buildroot}%{_mandir}/man8
install -D -m 0644 sbin/%{srvname}.in %{buildroot}%{_sbindir}/%{srvname}
install -d %{buildroot}%{_unitdir}
install -m 0644 service/* %{buildroot}%{_unitdir}
ln -s /usr/sbin/service %{buildroot}%{_sbindir}/rcsapping
ln -s /usr/sbin/service %{buildroot}%{_sbindir}/rcsappong

sed -i 's+@PYTHON@+%{_bindir}/python3+' %{buildroot}%{ocf_dir}/resource.d/suse/%{raname}
sed -i 's+@PYTHON@+%{_bindir}/python3+' %{buildroot}%{_sbindir}/%{srvname}

%if %{with test}
%check
pytest tests
%endif

%pre
%service_add_pre sapping.service sappong.service

%post
%service_add_post sapping.service sappong.service

%preun
%service_del_preun sapping.service sappong.service

%postun
%service_del_postun sapping.service sappong.service

%files
%defattr(-,root,root)
%license LICENSE
%doc README.md
%{_mandir}/man7/*.7.gz
%{_mandir}/man8/*.8.gz
%dir %{ocf_dir}
%dir %{ocf_dir}/resource.d
%dir %{ocf_dir}/resource.d/suse
%defattr(755,root,root,-)
%{ocf_dir}/resource.d/suse/%{raname}
%{_sbindir}/*
%defattr(644,root,root,-)
%{_unitdir}/*

%changelog
* Wed Feb 19 2025 abriel@suse.com
-  add compatibility with python 3.13
* Wed Aug 28 2024 abriel@suse.com
- add SLE16 support
* Mon Dec 11 2023 abriel@suse.com
- Version bump to 0.9.4
  * fix error in exception handling of sapstartsrv status function
    (bsc#1217276)
* Fri Aug  4 2023 abriel@suse.com
- Version bump to 0.9.3
  * adapt fix for monitor/probe operation to detect a running
    sapstartsrv process to run with python3-psutil version 5.2.2
    or higher
    (bsc#1210790)
* Wed May 24 2023 abriel@suse.com
- Version bump to 0.9.2
  * prevent systemd service race between sapping and sappong during
    system boot
    (bsc#1207138)
  * fix a problem of monitor/probe operation to detect a running
    sapstartsrv process
    (bsc#1210790)
- add python3-psutil as package requirement and as build
  requirement in case of testing
  needed for bsc#1210790
  (jsc#PED-4418, jsc#PED-4499)
* Wed Sep 14 2022 abriel@suse.com
- Version bump to 0.9.1
- man page updates based on customer feedback on conferences
- remove 'BuildRequire python3-mock' as this is no longer needed
  for the tests
* Fri Feb 25 2022 abriel@suse.com
- Add systemd support for the resource agent to interact with the
  new SAP unit files for sapstartsrv.
  As the new version of the SAP Startup Framework will use systemd
  unit files to control the sapstartsrv process instead of the
  previous used SysV init script, we need to adapt the handling of
  sapstartsrv inside the resource agents to support both ways.
  (bsc#1189529)
- prevent false posivite with pgrep in function '_get_status'
  (bsc#1193568)
* Thu Apr 22 2021 abriel@suse.com
- remove deprecated option "syslog" from the sapping.service and
  sappong.service files.
  (bsc#1185152)
* Wed Mar 31 2021 abriel@suse.com
- prevent sapping.service from running a second time after a
  corosync start/restart
  (bsc#1183969)
* Fri Mar  5 2021 xarbulu@suse.com
- Fix the spec file to follow properly the SLE submission policies
* Fri Dec  4 2020 fabian.herschel@suse.com
- Add sapservices-move script
* Wed Sep 16 2020 xarbulu@suse.com
- Simplified Cluster FS architecture for S/4HANA and NetWeaver
  It controls the instance specific sapstartsrv process which
  provides the API to start, stop and check a SAP instance.
  (jsc#ECO-3341, jsc#SLE-16935, jsc#SLE-17440)
- Include python version to the resource agent
